---
component_title: "GeoIP"
description: "The Vector [`geoip`](#geoip) transform accepts and outputs `log` events allowing you to enrich events with geolocation data from the MaxMind GeoIP2 and GeoLite2 city databases."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+geoip%22
min_version: null
service_name: "GeoIP"
sidebar_label: "geoip|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/geoip.rs
status: "beta"
title: "GeoIP Transform"
---

The Vector [`geoip`](#geoip) transform accepts and [outputs `log` events](#output) allowing you to enrich events with geolocation data from the MaxMind GeoIP2 and GeoLite2 city databases.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/geoip.md.erb
-->

## Configuration

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[transforms.my_transform_id]
  # REQUIRED
  type = "geoip" # must be: "geoip"
  inputs = ["my-source-id"] # example
  database = "/path/to/GeoLite2-City.mmdb" # example
  source = "ip_address" # example

  # OPTIONAL
  target = "geoip" # default
```

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/GeoLite2-City.mmdb"]}
  groups={[]}
  name={"database"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### database

Path to the MaxMind GeoIP2 or GeoLite2 binary city database file (`GeoLite2-City.mmdb`). Other databases, such as the the country database are not supported.



</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["ip_address","x-forwarded-for"]}
  groups={[]}
  name={"source"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### source

The field name that contains the IP address. This field should contain a valid IPv4 or IPv6 address.


</Field>


<Field
  common={true}
  defaultValue={"geoip"}
  enumValues={null}
  examples={["geoip"]}
  groups={[]}
  name={"target"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### target

The default field to insert the resulting GeoIP data into. See [output](#output) for more info.


</Field>


</Fields>

## Output

The [`geoip`](#geoip) transform accepts and [outputs `log` events](#output) allowing you to enrich events with geolocation data from the MaxMind GeoIP2 and GeoLite2 city databases.
For example:

```javascript
{
  "geoip": {
    "city_name": "New York",
    "continent_code": "AF",
    "country_code": "US",
    "latitude": "51.75",
    "longitude": "-1.25",
    "postal_code": "07094",
    "timezone": "America/New_York"
  }
}
```
More detail on the output schema is below.

<Fields filters={true}>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"geoip"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"struct"}
  unit={null}
  >

### geoip

The root field containing all geolocation data as sub-fields.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["New York","Brooklyn","Chicago"]}
  groups={[]}
  name={"city_name"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### city_name

The city name associated with the IP address.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={{"AF":"Africa","AN":"Antarctica","AS":"Asia","EU":"Europe","NA":"North America","OC":"Oceania","SA":"South America"}}
  examples={["AF","AN","AS","EU","NA","OC","SA"]}
  groups={[]}
  name={"continent_code"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### continent_code

The continent code associated with the IP address.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["US","US-PR","FR","FR-BL","GB","A1","A2"]}
  groups={[]}
  name={"country_code"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### country_code

The [ISO 3166-2 country codes][urls.iso3166-2] associated with the IP address.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["51.75"]}
  groups={[]}
  name={"latitude"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### latitude

The latitude associated with the IP address.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["-1.25"]}
  groups={[]}
  name={"longitude"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### longitude

The longitude associated with the IP address.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["07094","10010","OX1"]}
  groups={[]}
  name={"postal_code"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### postal_code

The postal code associated with the IP address.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["America/New_York","Asia/Atyrau","Europe/London"]}
  groups={[]}
  name={"timezone"}
  path={"geoip"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### timezone

The timezone associated with the IP address in [IANA time zone format][urls.iana_time_zone_format]. A full list of time zones can be found [here][urls.iana_time_zones].



</Field>


</Fields>

</Field>


</Fields>

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[urls.iana_time_zone_format]: https://en.wikipedia.org/wiki/Tz_database#Names_of_time_zones
[urls.iana_time_zones]: https://en.wikipedia.org/wiki/List_of_tz_database_time_zones
[urls.iso3166-2]: https://en.wikipedia.org/wiki/ISO_3166-2
