---
title: Install Vector From Archives
sidebar_label: From Archives
description: Install Vector from pre-compiled archives
---


This page covers installing Vector from a pre-built archive. These archives
contain the `vector` binary as well as supporting configuration files.

import Alert from '@site/src/components/Alert';

<Alert type="warning">

We recommend installing Vector through a supported [container
platform][docs.containers] or [package manager][docs.package_managers], if
possible. These handle permissions, directory creation, and other
intricacies covered in the [Next Steps](#next-steps) section.

</Alert>

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/setup/installation/manual/from-archives.md.erb
-->

## Installation

import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

<Tabs
  block={true}
  defaultValue="vector-x86_64-unknown-linux-musl.tar.gz"
  urlKey="file_name"
  values={[{"label":"Linux (x86_64)","value":"vector-x86_64-unknown-linux-musl.tar.gz"},{"label":"Linux (ARM64)","value":"vector-aarch64-unknown-linux-musl.tar.gz"},{"label":"Linux (ARMv7)","value":"vector-armv7-unknown-linux-musleabihf.tar.gz"},{"label":"MacOS (x86_64)","value":"vector-x86_64-apple-darwin.tar.gz"},{"label":"Windows (x86_64, 7+)","value":"vector-x86_64-pc-windows-msvc.zip"}]}>


<TabItem value="vector-x86_64-unknown-linux-musl.tar.gz">


1.  Download & unpack the archive

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.8.0)', value: 'latest'},
        { label: 'Nightly', value: 'nightly'},
      ]}>

    <TabItem value="latest">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://packages.timber.io/vector/0.8.X/vector-x86_64-unknown-linux-musl.tar.gz | \
      tar xzf - -C vector --strip-components=2
    ```

    </TabItem>
    <TabItem value="nightly">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://packages.timber.io/vector/nightly/latest/vector-x86_64-unknown-linux-musl.tar.gz | \
      tar xzf - -C vector --strip-components=2
    ```

    </TabItem>
    </Tabs>

2.  Change into the `vector` directory

    ```bash
    cd vector
    ```

3.  Move `vector` into your $PATH

    ```bash
    echo "export PATH=\"$(pwd)/vector/bin:\$PATH\"" >> $HOME/.profile
    source $HOME/.profile
    ```

4.  Start Vector

    That's it! You can start vector with:

    ```bash
    vector --config config/vector.toml
    ```

</TabItem>

<TabItem value="vector-aarch64-unknown-linux-musl.tar.gz">


1.  Download & unpack the archive

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.8.0)', value: 'latest'},
        { label: 'Nightly', value: 'nightly'},
      ]}>

    <TabItem value="latest">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://packages.timber.io/vector/0.8.X/vector-aarch64-unknown-linux-musl.tar.gz | \
      tar xzf - -C vector --strip-components=2
    ```

    </TabItem>
    <TabItem value="nightly">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://packages.timber.io/vector/nightly/latest/vector-aarch64-unknown-linux-musl.tar.gz | \
      tar xzf - -C vector --strip-components=2
    ```

    </TabItem>
    </Tabs>

2.  Change into the `vector` directory

    ```bash
    cd vector
    ```

3.  Move `vector` into your $PATH

    ```bash
    echo "export PATH=\"$(pwd)/vector/bin:\$PATH\"" >> $HOME/.profile
    source $HOME/.profile
    ```

4.  Start Vector

    That's it! You can start vector with:

    ```bash
    vector --config config/vector.toml
    ```

</TabItem>

<TabItem value="vector-armv7-unknown-linux-musleabihf.tar.gz">


1.  Download & unpack the archive

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.8.0)', value: 'latest'},
        { label: 'Nightly', value: 'nightly'},
      ]}>

    <TabItem value="latest">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://packages.timber.io/vector/0.8.X/vector-armv7-unknown-linux-musleabihf.tar.gz | \
      tar xzf - -C vector --strip-components=2
    ```

    </TabItem>
    <TabItem value="nightly">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://packages.timber.io/vector/nightly/latest/vector-armv7-unknown-linux-musleabihf.tar.gz | \
      tar xzf - -C vector --strip-components=2
    ```

    </TabItem>
    </Tabs>

2.  Change into the `vector` directory

    ```bash
    cd vector
    ```

3.  Move `vector` into your $PATH

    ```bash
    echo "export PATH=\"$(pwd)/vector/bin:\$PATH\"" >> $HOME/.profile
    source $HOME/.profile
    ```

4.  Start Vector

    That's it! You can start vector with:

    ```bash
    vector --config config/vector.toml
    ```

</TabItem>

<TabItem value="vector-x86_64-apple-darwin.tar.gz">


1.  Download & unpack the archive

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.8.0)', value: 'latest'},
        { label: 'Nightly', value: 'nightly'},
      ]}>

    <TabItem value="latest">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://packages.timber.io/vector/0.8.X/vector-x86_64-apple-darwin.tar.gz | \
      tar xzf - -C vector --strip-components=2
    ```

    </TabItem>
    <TabItem value="nightly">

    ```bash
    mkdir -p vector && \
      curl -sSfL --proto '=https' --tlsv1.2 https://packages.timber.io/vector/nightly/latest/vector-x86_64-apple-darwin.tar.gz | \
      tar xzf - -C vector --strip-components=2
    ```

    </TabItem>
    </Tabs>

2.  Change into the `vector` directory

    ```bash
    cd vector
    ```

3.  Move `vector` into your $PATH

    ```bash
    echo "export PATH=\"$(pwd)/vector/bin:\$PATH\"" >> $HOME/.profile
    source $HOME/.profile
    ```

4.  Start Vector

    That's it! You can start vector with:

    ```bash
    vector --config config/vector.toml
    ```

</TabItem>

<TabItem value="vector-x86_64-pc-windows-msvc.zip">


1.  Download Vector release archive (latest):

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.8.0)', value: 'latest'},
        { label: 'Nightly', value: 'nightly'},
      ]}>

    <TabItem value="latest">

    ```bat
    powershell Invoke-WebRequest https://packages.timber.io/vector/0.8.X/vector-x86_64-pc-windows-msvc.zip -OutFile vector-x86_64-pc-windows-msvc.zip
    ```

    </TabItem>
    <TabItem value="nightly">

    ```bat
    powershell Invoke-WebRequest https://packages.timber.io/vector/nightly/latest/vector-x86_64-pc-windows-msvc.zip -OutFile vector-x86_64-pc-windows-msvc.zip
    ```

    </TabItem>
    </Tabs>

2.  Extract files from the archive:

    ```bat
    powershell Expand-Archive vector-x86_64-pc-windows-msvc.zip .
    ```

3.  Navigate to the Vector directory:

    ```bat
    cd vector-x86_64-pc-windows-msvc
    ```
4.  Start Vector:

    ```bat
    .\bin\vector --config config\vector.toml
    ```

</TabItem>
</Tabs>

## Next Steps

### Configuring

The Vector configuration file is located at:

```
config/vector.toml
```

A full spec is located at `config/vector.spec.toml` and examples are
located in `config/vector/examples/*`. You can learn more about configuring
Vector in the [Configuration][docs.configuration] section.

### Data Directory

We highly recommend creating a [data directory][docs.global-options#data_dir]
that Vector can use:

```
mkdir /var/lib/vector
```

<Alert type="warning">

Make sure that this directory is writable by the `vector` process.

</Alert>

Vector offers a global [`data_dir` option][docs.global-options#data_dir] that
you can use to specify the path of your directory.

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" />

```toml
data_dir = "/var/lib/vector" # default
```

### Service Managers

Vector archives ship with service files in case you need them:

#### Init.d

To install Vector into Init.d run:

```bash
cp -av etc/init.d/vector /etc/init.d
```

#### Systemd

To install Vector into Systemd run:

```bash
cp -av etc/systemd/vector.service /etc/systemd/system
```

### Updating

Simply follow the same [installation instructions above](#installation).


[docs.configuration]: /docs/setup/configuration/
[docs.containers]: /docs/setup/installation/containers/
[docs.global-options#data_dir]: /docs/reference/global-options/#data_dir
[docs.package_managers]: /docs/setup/installation/package-managers/
